@@ -28,7 +28,10 @@ class instance:
         return str(self.data)
 
     def __len__(self):
-        return len(self.data);
+        return self.Length
+
+    def __int__(self):
+        return self.Length
     """
         Name: Substr
         Params: Int32 offset
