@@ -43,4 +43,9 @@ def test_st_format():
 def test_len():
 	msg = instance("hello");
 	test = len(msg);
+	assert(test == 5);
+
+def test_int():
+	msg = instance("hello");
+	test = int(msg);
 	assert(test == 5);
\ No newline at end of file
